pub struct ListJobsResponse {
pub jobs: Option<Vec<Job>>,
pub next_page_token: Option<String>,
}Expand description
Response message for listing jobs using ListJobs.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- locations jobs list projects (response)
Fields
jobs: Option<Vec<Job>>The list of jobs.
next_page_token: Option<String>A token to retrieve next page of results. Pass this value in the page_token field in the subsequent call to ListJobs to retrieve the next page of results. If this is empty it indicates that there are no more results through which to paginate. The page token is valid for only 2 hours.