pub struct RunJobRequest {
pub legacy_app_engine_cron: Option<bool>,
}Expand description
Request message for forcing a job to run now using RunJob.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- locations jobs run projects (request)
Fields
legacy_app_engine_cron: Option<bool>This field is used to manage the legacy App Engine Cron jobs using the Cloud Scheduler API. If the field is set to true, the job in the __cron queue with the corresponding name will be forced to run instead.